# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui_pyqtgraph_rev2_1.ui'
#
# Created by: PyQt5 UI code generator 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(1366, 768)
        font = QtGui.QFont()
        font.setFamily("Calibri Light")
        font.setPointSize(11)
        Form.setFont(font)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.s1 = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.s1.sizePolicy().hasHeightForWidth())
        self.s1.setSizePolicy(sizePolicy)
        self.s1.setObjectName("s1")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.s1)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.s1_lb_2 = QtWidgets.QLabel(self.s1)
        self.s1_lb_2.setObjectName("s1_lb_2")
        self.gridLayout_2.addWidget(self.s1_lb_2, 1, 0, 1, 1)
        self.s1_lb_1 = QtWidgets.QLabel(self.s1)
        self.s1_lb_1.setObjectName("s1_lb_1")
        self.gridLayout_2.addWidget(self.s1_lb_1, 0, 0, 1, 1)
        self.s1_bt_1 = QtWidgets.QPushButton(self.s1)
        self.s1_bt_1.setObjectName("s1_bt_1")
        self.gridLayout_2.addWidget(self.s1_bt_1, 0, 1, 1, 1)
        self.s1_bt_5 = QtWidgets.QPushButton(self.s1)
        self.s1_bt_5.setObjectName("s1_bt_5")
        self.gridLayout_2.addWidget(self.s1_bt_5, 6, 0, 1, 1)
        self.s1_bt_6 = QtWidgets.QPushButton(self.s1)
        self.s1_bt_6.setObjectName("s1_bt_6")
        self.gridLayout_2.addWidget(self.s1_bt_6, 6, 1, 1, 1)
        self.s1_lb_3 = QtWidgets.QLabel(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s1_lb_3.sizePolicy().hasHeightForWidth())
        self.s1_lb_3.setSizePolicy(sizePolicy)
        self.s1_lb_3.setObjectName("s1_lb_3")
        self.gridLayout_2.addWidget(self.s1_lb_3, 2, 0, 1, 2)
        self.s1_bt_2 = QtWidgets.QComboBox(self.s1)
        self.s1_bt_2.setObjectName("s1_bt_2")
        self.gridLayout_2.addWidget(self.s1_bt_2, 1, 1, 1, 1)
        self.s1_lb_4 = QtWidgets.QLabel(self.s1)
        self.s1_lb_4.setObjectName("s1_lb_4")
        self.gridLayout_2.addWidget(self.s1_lb_4, 4, 0, 1, 1)
        self.s1_bt_4 = QtWidgets.QComboBox(self.s1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.s1_bt_4.sizePolicy().hasHeightForWidth())
        self.s1_bt_4.setSizePolicy(sizePolicy)
        self.s1_bt_4.setObjectName("s1_bt_4")
        self.s1_bt_4.addItem("")
        self.s1_bt_4.addItem("")
        self.gridLayout_2.addWidget(self.s1_bt_4, 4, 1, 1, 1)
        self.gridLayout.addWidget(self.s1, 0, 0, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(5)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.s2_lb_1 = QtWidgets.QLabel(self.groupBox_2)
        self.s2_lb_1.setObjectName("s2_lb_1")
        self.gridLayout_3.addWidget(self.s2_lb_1, 0, 0, 1, 1)
        self.s2_di_1 = QtWidgets.QDial(self.groupBox_2)
        self.s2_di_1.setObjectName("s2_di_1")
        self.gridLayout_3.addWidget(self.s2_di_1, 0, 1, 1, 1)
        self.s2_lb_2 = QtWidgets.QLabel(self.groupBox_2)
        self.s2_lb_2.setObjectName("s2_lb_2")
        self.gridLayout_3.addWidget(self.s2_lb_2, 1, 0, 1, 1)
        self.s2_di_2 = QtWidgets.QDial(self.groupBox_2)
        self.s2_di_2.setObjectName("s2_di_2")
        self.gridLayout_3.addWidget(self.s2_di_2, 1, 1, 1, 1)
        self.s2_bt_3 = QtWidgets.QPushButton(self.groupBox_2)
        self.s2_bt_3.setObjectName("s2_bt_3")
        self.gridLayout_3.addWidget(self.s2_bt_3, 2, 1, 1, 1)
        self.s2_lb_3 = QtWidgets.QLabel(self.groupBox_2)
        self.s2_lb_3.setObjectName("s2_lb_3")
        self.gridLayout_3.addWidget(self.s2_lb_3, 3, 0, 1, 2)
        self.gridLayout.addWidget(self.groupBox_2, 1, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.s3_lb_1 = QtWidgets.QLabel(self.groupBox_3)
        self.s3_lb_1.setObjectName("s3_lb_1")
        self.gridLayout_4.addWidget(self.s3_lb_1, 0, 0, 1, 1)
        self.s3_line_1 = QtWidgets.QLineEdit(self.groupBox_3)
        self.s3_line_1.setObjectName("s3_line_1")
        self.gridLayout_4.addWidget(self.s3_line_1, 0, 1, 1, 1)
        self.s3_lb_2 = QtWidgets.QLabel(self.groupBox_3)
        self.s3_lb_2.setObjectName("s3_lb_2")
        self.gridLayout_4.addWidget(self.s3_lb_2, 1, 0, 1, 1)
        self.s3_line_2 = QtWidgets.QLineEdit(self.groupBox_3)
        self.s3_line_2.setObjectName("s3_line_2")
        self.gridLayout_4.addWidget(self.s3_line_2, 1, 1, 1, 1)
        self.s3_lb_3 = QtWidgets.QLabel(self.groupBox_3)
        self.s3_lb_3.setObjectName("s3_lb_3")
        self.gridLayout_4.addWidget(self.s3_lb_3, 2, 0, 1, 1)
        self.s3_line_3 = QtWidgets.QLineEdit(self.groupBox_3)
        self.s3_line_3.setObjectName("s3_line_3")
        self.gridLayout_4.addWidget(self.s3_line_3, 2, 1, 1, 1)
        self.gridLayout.addWidget(self.groupBox_3, 2, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(5)
        sizePolicy.setHeightForWidth(self.groupBox_4.sizePolicy().hasHeightForWidth())
        self.groupBox_4.setSizePolicy(sizePolicy)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.s4_lb_1 = QtWidgets.QLabel(self.groupBox_4)
        self.s4_lb_1.setObjectName("s4_lb_1")
        self.gridLayout_6.addWidget(self.s4_lb_1, 0, 1, 1, 1)
        self.s4_bt_1 = QtWidgets.QPushButton(self.groupBox_4)
        self.s4_bt_1.setObjectName("s4_bt_1")
        self.gridLayout_6.addWidget(self.s4_bt_1, 2, 3, 1, 1)
        self.s4_bt_3 = QtWidgets.QPushButton(self.groupBox_4)
        self.s4_bt_3.setObjectName("s4_bt_3")
        self.gridLayout_6.addWidget(self.s4_bt_3, 3, 5, 1, 1)
        self.s4_line_2 = QtWidgets.QLCDNumber(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(4)
        sizePolicy.setHeightForWidth(self.s4_line_2.sizePolicy().hasHeightForWidth())
        self.s4_line_2.setSizePolicy(sizePolicy)
        self.s4_line_2.setMinimumSize(QtCore.QSize(0, 3))
        self.s4_line_2.setObjectName("s4_line_2")
        self.gridLayout_6.addWidget(self.s4_line_2, 2, 2, 1, 1)
        self.s4_line_1 = QtWidgets.QLCDNumber(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.s4_line_1.sizePolicy().hasHeightForWidth())
        self.s4_line_1.setSizePolicy(sizePolicy)
        self.s4_line_1.setObjectName("s4_line_1")
        self.gridLayout_6.addWidget(self.s4_line_1, 2, 1, 1, 1)
        self.s4_lb_2 = QtWidgets.QLabel(self.groupBox_4)
        self.s4_lb_2.setObjectName("s4_lb_2")
        self.gridLayout_6.addWidget(self.s4_lb_2, 0, 2, 1, 1)
        self.s4_line_3 = QtWidgets.QLineEdit(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.s4_line_3.sizePolicy().hasHeightForWidth())
        self.s4_line_3.setSizePolicy(sizePolicy)
        self.s4_line_3.setObjectName("s4_line_3")
        self.gridLayout_6.addWidget(self.s4_line_3, 3, 2, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_6.addItem(spacerItem, 3, 3, 1, 1)
        self.s4_bt_2 = QtWidgets.QPushButton(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.s4_bt_2.sizePolicy().hasHeightForWidth())
        self.s4_bt_2.setSizePolicy(sizePolicy)
        self.s4_bt_2.setObjectName("s4_bt_2")
        self.gridLayout_6.addWidget(self.s4_bt_2, 2, 5, 1, 1)
        self.s4_lb_3 = QtWidgets.QLabel(self.groupBox_4)
        self.s4_lb_3.setObjectName("s4_lb_3")
        self.gridLayout_6.addWidget(self.s4_lb_3, 3, 1, 1, 1)
        self.gridLayout.addWidget(self.groupBox_4, 2, 1, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(9)
        sizePolicy.setVerticalStretch(9)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.lb_photo = QtWidgets.QLabel(self.tab)
        self.lb_photo.setText("")
        self.lb_photo.setObjectName("lb_photo")
        self.gridLayout_7.addWidget(self.lb_photo, 0, 0, 1, 5)
        self.bt_cam = QtWidgets.QComboBox(self.tab)
        self.bt_cam.setObjectName("bt_cam")
        self.bt_cam.addItem("")
        self.gridLayout_7.addWidget(self.bt_cam, 1, 1, 1, 1)
        self.lb_select_cam = QtWidgets.QLabel(self.tab)
        self.lb_select_cam.setObjectName("lb_select_cam")
        self.gridLayout_7.addWidget(self.lb_select_cam, 1, 0, 1, 1)
        self.bt_cam_start = QtWidgets.QPushButton(self.tab)
        self.bt_cam_start.setObjectName("bt_cam_start")
        self.gridLayout_7.addWidget(self.bt_cam_start, 1, 3, 1, 1)
        self.bt_cam_stop = QtWidgets.QPushButton(self.tab)
        self.bt_cam_stop.setObjectName("bt_cam_stop")
        self.gridLayout_7.addWidget(self.bt_cam_stop, 1, 4, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(300, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_7.addItem(spacerItem1, 1, 2, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.lb_thers_set = QtWidgets.QLabel(self.tab_2)
        self.lb_thers_set.setObjectName("lb_thers_set")
        self.gridLayout_8.addWidget(self.lb_thers_set, 1, 0, 1, 1)
        self.bt_thers_set = QtWidgets.QComboBox(self.tab_2)
        self.bt_thers_set.setObjectName("bt_thers_set")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.bt_thers_set.addItem("")
        self.gridLayout_8.addWidget(self.bt_thers_set, 1, 1, 1, 1)
        self.bt_start_draw = QtWidgets.QPushButton(self.tab_2)
        self.bt_start_draw.setObjectName("bt_start_draw")
        self.gridLayout_8.addWidget(self.bt_start_draw, 1, 3, 1, 1)
        self.bt_stop_draw = QtWidgets.QPushButton(self.tab_2)
        self.bt_stop_draw.setObjectName("bt_stop_draw")
        self.gridLayout_8.addWidget(self.bt_stop_draw, 1, 4, 1, 1)
        self.bt_save_data = QtWidgets.QPushButton(self.tab_2)
        self.bt_save_data.setObjectName("bt_save_data")
        self.gridLayout_8.addWidget(self.bt_save_data, 1, 5, 1, 1)
        self.plot_widget = GraphicsLayoutWidget(self.tab_2)
        self.plot_widget.setObjectName("plot_widget")
        self.gridLayout_8.addWidget(self.plot_widget, 0, 0, 1, 6)
        spacerItem2 = QtWidgets.QSpacerItem(300, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_8.addItem(spacerItem2, 1, 2, 1, 1)
        self.tabWidget.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.raw_broswer = QtWidgets.QTextBrowser(self.tab_3)
        self.raw_broswer.setObjectName("raw_broswer")
        self.gridLayout_5.addWidget(self.raw_broswer, 0, 0, 1, 1)
        self.tabWidget.addTab(self.tab_3, "")
        self.gridLayout.addWidget(self.tabWidget, 0, 1, 2, 1)

        self.retranslateUi(Form)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.s1.setTitle(_translate("Form", "裝置設定"))
        self.s1_lb_2.setText(_translate("Form", "USB serial"))
        self.s1_lb_1.setText(_translate("Form", "檢查裝置"))
        self.s1_bt_1.setText(_translate("Form", "檢查裝置"))
        self.s1_bt_5.setText(_translate("Form", "start"))
        self.s1_bt_6.setText(_translate("Form", "pause"))
        self.s1_lb_3.setText(_translate("Form", "當前裝置"))
        self.s1_lb_4.setText(_translate("Form", "裝置類型"))
        self.s1_bt_4.setItemText(0, _translate("Form", "XMC1302"))
        self.s1_bt_4.setItemText(1, _translate("Form", "microbit"))
        self.groupBox_2.setTitle(_translate("Form", "回控設定"))
        self.s2_lb_1.setText(_translate("Form", "最小閥值"))
        self.s2_lb_2.setText(_translate("Form", "最大閥值"))
        self.s2_bt_3.setText(_translate("Form", "send"))
        self.s2_lb_3.setText(_translate("Form", "設置參數"))
        self.groupBox_3.setTitle(_translate("Form", "系統資訊"))
        self.s3_lb_1.setText(_translate("Form", "開啟時間"))
        self.s3_lb_2.setText(_translate("Form", "當前時間"))
        self.s3_lb_3.setText(_translate("Form", "使用者"))
        self.groupBox_4.setTitle(_translate("Form", "狀態顯示"))
        self.s4_lb_1.setText(_translate("Form", "當前速度"))
        self.s4_bt_1.setText(_translate("Form", "紀錄速度"))
        self.s4_bt_3.setText(_translate("Form", "存取紀錄"))
        self.s4_lb_2.setText(_translate("Form", "Duppler Freq"))
        self.s4_bt_2.setText(_translate("Form", "暫停紀錄"))
        self.s4_lb_3.setText(_translate("Form", "當前狀態"))
        self.bt_cam.setItemText(0, _translate("Form", "默認攝影機(0)"))
        self.lb_select_cam.setText(_translate("Form", "選擇攝影機"))
        self.bt_cam_start.setText(_translate("Form", "開啟攝影"))
        self.bt_cam_stop.setText(_translate("Form", "暫停攝影"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("Form", "攝影機資料"))
        self.lb_thers_set.setText(_translate("Form", "設置參考線"))
        self.bt_thers_set.setItemText(0, _translate("Form", "250"))
        self.bt_thers_set.setItemText(1, _translate("Form", "500"))
        self.bt_thers_set.setItemText(2, _translate("Form", "1000"))
        self.bt_thers_set.setItemText(3, _translate("Form", "1500"))
        self.bt_thers_set.setItemText(4, _translate("Form", "2000"))
        self.bt_thers_set.setItemText(5, _translate("Form", "2500"))
        self.bt_start_draw.setText(_translate("Form", "開啟繪製"))
        self.bt_stop_draw.setText(_translate("Form", "暫停繪製"))
        self.bt_save_data.setText(_translate("Form", "存取當前資料"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("Form", "原始圖表"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), _translate("Form", "原始輸入"))


from pyqtgraph import GraphicsLayoutWidget
